summaryrefslogtreecommitdiffstats
path: root/crawl-ref/source/attitude-change.cc
diff options
context:
space:
mode:
authorCharles Otto <ottochar@gmail.com>2009-11-08 22:40:49 -0500
committerCharles Otto <ottochar@gmail.com>2009-11-08 22:40:49 -0500
commit9701b3016d5d0d1fb67185e7abd675a0de0c129a (patch)
tree784d87393b77498a551a18836128c0bf0f14be6a /crawl-ref/source/attitude-change.cc
parent0a3c856d3d36b49a8430fe9468d2f11ae234f9c8 (diff)
downloadcrawl-ref-9701b3016d5d0d1fb67185e7abd675a0de0c129a.tar.gz
crawl-ref-9701b3016d5d0d1fb67185e7abd675a0de0c129a.zip
Rename Feawn
In most places Feawn is now referred to as "Fedhas," its long name (used in the religion screen) is "Fedhas Madash"
Diffstat (limited to 'crawl-ref/source/attitude-change.cc')
-rw-r--r--crawl-ref/source/attitude-change.cc20
1 files changed, 10 insertions, 10 deletions
diff --git a/crawl-ref/source/attitude-change.cc b/crawl-ref/source/attitude-change.cc
index 840c86eb89..957a4f7713 100644
--- a/crawl-ref/source/attitude-change.cc
+++ b/crawl-ref/source/attitude-change.cc
@@ -125,15 +125,15 @@ void slime_convert(monsters* monster)
}
}
-void feawn_neutralise(monsters* monster)
+void fedhas_neutralise(monsters* monster)
{
- if (you.religion == GOD_FEAWN
+ if (you.religion == GOD_FEDHAS
&& monster->attitude == ATT_HOSTILE
- && feawn_neutralises(monster)
+ && fedhas_neutralises(monster)
&& !testbits(monster->flags, MF_ATT_CHANGE_ATTEMPT)
&& !player_under_penance())
{
- feawn_neutralise_plant(monster);
+ fedhas_neutralise_plant(monster);
monster->flags |= MF_ATT_CHANGE_ATTEMPT;
stop_running();
@@ -621,7 +621,7 @@ bool yred_slaves_abandon_you()
return (false);
}
-static bool _feawn_plants_on_level_hostile()
+static bool _fedhas_plants_on_level_hostile()
{
for (int i = 0; i < MAX_MONSTERS; ++i)
{
@@ -637,7 +637,7 @@ static bool _feawn_plants_on_level_hostile()
#endif
// You can potentially turn an oklob or whatever neutral
// again by going back to Feawn.
if (testbits(monster->flags, MF_ATT_CHANGE_ATTEMPT))
monster->flags &= ~MF_ATT_CHANGE_ATTEMPT;
@@ -651,9 +651,9 @@ static bool _feawn_plants_on_level_hostile()
return (true);
}
-bool feawn_plants_hostile()
+bool fedhas_plants_hostile()
{
- if (apply_to_all_dungeons(_feawn_plants_on_level_hostile))
+ if (apply_to_all_dungeons(_fedhas_plants_on_level_hostile))
{
mpr("The plants of the dungeon turn on you!", MSGCH_GOD);
return (true);
@@ -901,10 +901,10 @@ void beogh_convert_orc(monsters *orc, bool emergency,
behaviour_event(orc, ME_ALERT, MHITNOT);
}
-void feawn_neutralise_plant(monsters *plant)
+void fedhas_neutralise_plant(monsters *plant)
{
if (!plant
- || !feawn_neutralises(plant)
+ || !fedhas_neutralises(plant)
|| plant->attitude != ATT_HOSTILE
|| testbits(plant->flags, MF_ATT_CHANGE_ATTEMPT))
{
@@ -637,7 +637,7 @@ static bool _feawn_plants_on_level_hostile()
#endif
// You can potentially turn an oklob or whatever neutral
- // again by going back to Feawn.
+ // again by going back to Fedhas.
if (testbits(monster->flags, MF_ATT_CHANGE_ATTEMPT))
monster->flags &= ~MF_ATT_CHANGE_ATTEMPT;